ImageRefExt

Trait ImageRefExt 

pub trait ImageRefExt: ImageRef {
    // Provided methods
    fn bounds_check(&self) -> Result<(), BoundsCheckError> { ... }
    fn crop(self, window: Window) -> Result<Cropped<Self>, CropError>
       where Self: Sized { ... }
    fn crop_even(self) -> Result<Cropped<Self>, CropError>
       where Self: Sized { ... }
}
ImageRef extension methods

Provided Methods

fn bounds_check(&self) -> Result<(), BoundsCheckError>

Perform a bounds check, return an error when it fails

fn crop(self, window: Window) -> Result<Cropped<Self>, CropError>
where Self: Sized,

Crop the image with the given window

fn crop_even(self) -> Result<Cropped<Self>, CropError>
where Self: Sized,

Crop the image to the next lowest even resolution

Implementors