pub enum PixelFormat {
Show 15 variants
I420,
I422,
I444,
I010,
I012,
I210,
I212,
I410,
I412,
NV12,
YUYV,
RGBA,
BGRA,
RGB,
BGR,
}Expand description
Supported pixel formats
Variants
I420
Y, U and V planes, 4:2:0 sub sampling, 8 bits per sample
I422
Y, U and V planes, 4:2:2 sub sampling, 8 bits per sample
I444
Y, U and V planes, 4:4:4 sub sampling, 8 bits per sample
I010
Y, U, and V planes, 4:2:0 sub sampling, 10 bits per sample
I012
Y, U, and V planes, 4:2:0 sub sampling, 12 bits per sample
I210
Y, U, and V planes, 4:2:2 sub sampling, 10 bits per sample
I212
Y, U, and V planes, 4:2:2 sub sampling, 10 bits per sample
I410
Y, U, and V planes, 4:4:4 sub sampling, 10 bits per sample
I412
Y, U, and V planes, 4:4:4 sub sampling, 12 bits per sample
NV12
Y and interleaved UV planes, 4:2:0 sub sampling
YUYV
Single YUYV, 4:2:2 sub sampling
RGBA
Single RGBA interleaved plane
BGRA
Single BGRA interleaved plane
RGB
Single RGB interleaved plane
BGR
Single BGR interleaved plane
Implementations
Sourceimpl PixelFormat
impl PixelFormat
Sourcepub fn buffer_size(self, width: usize, height: usize) -> usize
pub fn buffer_size(self, width: usize, height: usize) -> usize
Calculate the required buffer size given the PixelFormat self and image dimensions (in pixel width, height).
The size is the amount of primitives (u8, u16) so when allocating size this must be accounted for.
Sourcepub fn packed_strides(self, width: usize) -> Vec<usize>
pub fn packed_strides(self, width: usize) -> Vec<usize>
Calculate the strides of an image in a packed buffer
Sourcepub fn bounds_check<'a>(
self,
planes: impl Iterator<Item = (&'a [u8], usize)>,
width: usize,
height: usize,
) -> Result<(), BoundsCheckError>
pub fn bounds_check<'a>( self, planes: impl Iterator<Item = (&'a [u8], usize)>, width: usize, height: usize, ) -> Result<(), BoundsCheckError>
Check if the given planes+strides are valid for dimensions
pub fn bits_per_component(&self) -> usize
pub fn variants() -> impl IntoIterator<Item = Self>